@@ -7,10 +7,10 @@ from suite_py.lib import logger
 
 
 class IP:
-    def __init__(self, project, env):
+    def __init__(self, project, config, env):
         self._project = project
         self._env = env
-        self._aws = Aws()
+        self._aws = Aws(config)
 
     def run(self):
 
