@@ -1,17 +1,34 @@
 # -*- encoding: utf-8 -*-
 import sys
 import time
+import os
 import boto3
 from halo import Halo
 from suite_py.lib import logger
 
 
 class Aws:
-    def __init__(self):
-        self._cloudformation = boto3.client("cloudformation", region_name="eu-west-1")
-        self._cloudfront = boto3.client("cloudfront", region_name="eu-west-1")
-        self._ecs = boto3.client("ecs", region_name="eu-west-1")
-        self._ec2 = boto3.client("ec2", region_name="eu-west-1")
+    def __init__(self, config):
+        self._profile = ""
+        if "profile" in config.aws:
+            self._profile = config.aws["profile"]
+        if os.getenv("AWS_PROFILE", None):
+            self._profile = os.getenv("AWS_PROFILE", None)
+
+        if not self._profile:
+            logger.warning(
+                "Please update your config file:\n'aws:\n    profile: <aws profile name>' "
+            )
+            logger.warning("Or set 'AWS_PROFILE=<aws profile name>'")
+            sys.exit(-1)
+
+        self._session = boto3.session.Session(profile_name=self._profile)
+        self._cloudformation = self._session.client(
+            "cloudformation", region_name="eu-west-1"
+        )
+        self._cloudfront = self._session.client("cloudfront", region_name="eu-west-1")
+        self._ecs = self._session.client("ecs", region_name="eu-west-1")
+        self._ec2 = self._session.client("ec2", region_name="eu-west-1")
 
     def update_stack(self, stack_name, version):
         params = self.update_template_params(stack_name, version)
