@@ -66,6 +66,9 @@ class YoutrackHandler:
                 return id_card
         return None
 
+    def get_ids_from_release_body(self, body):
+        return list(set(re.findall(REGEX, body)))
+
 
 def replace_card_names_with_md_links(text):
     return re.sub(REGEX, f"[\\1]({URL}\\1)", text)
